@@ -554,7 +554,7 @@ def eegRDM_bydecoding(EEG_data, sub_opt=1, time_win=5, time_step=5, navg=5, time
     for con1 in range(cons):
         for con2 in range(cons):
 
-            if con1 >= con2:
+            if con1 > con2:
 
                 data = np.concatenate((EEG_data[con1], EEG_data[con2]), axis=1)
                 print(data.shape)
@@ -564,7 +564,7 @@ def eegRDM_bydecoding(EEG_data, sub_opt=1, time_win=5, time_step=5, navg=5, time
                 rdms[:, :, con1, con2] = tbyt_decoding_kfold(data, labels, n=2, navg=navg, time_opt=time_opt,
                                                              time_win=time_win, time_step=time_step, nfolds=nfolds,
                                                              nrepeats=nrepeats, normalization=normalization,
-                                                             smooth=True)
+                                                             pca=False, smooth=True)
                 rdms[:, :, con2, con1] = rdms[:, :, con1, con2]
 
     if sub_opt == 0:
