@@ -237,12 +237,10 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
     step = float(1 / cons)
     for i in range(cons):
         for j in range(cons):
-            print(i, j)
-            text = plt.text(i * step + 0.5 * step, 1 - j * step - 0.5 * step, float('%.4f' % rdm[i, j]),
+            plt.text(i * step + 0.5 * step, 1 - j * step - 0.5 * step, float('%.4f' % rdm[i, j]),
                             ha="center", va="center", color="blue", fontsize=value_fontsize)
 
     if conditions != None:
-        print("1")
         step = float(1 / cons)
         x = np.arange(0.5 * step, 1 + 0.5 * step, step)
         y = np.arange(1 - 0.5 * step, -0.5 * step, -step)
@@ -251,6 +249,8 @@ def plot_rdm_withvalue(rdm, lim=[0, 1], value_fontsize=10, conditions=None, con_
     else:
         plt.axis("off")
 
+    plt.title(title, fontsize=title_fontsize)
+
     plt.show()
 
     return 0
@@ -356,6 +356,8 @@ def plot_corrs_by_time(corrs, labels=None, time_unit=[0, 0.1], title=None, title
     ax.spines['top'].set_visible(False)
     ax.spines['right'].set_visible(False)
 
+    plt.title(title, fontsize=title_fontsize)
+
     plt.show()
 
     return 0
@@ -485,6 +487,17 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
             else:
                 ps[t] = 0
 
+    print('\nSignificant time-windows:')
+    for t in range(nts):
+        if t == 0 and ps[t] == 1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps[t] == 1 and ps[t - 1] == 0:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps[t] == 1 and ps[t + 1] == 0:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps[t] == 1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
     for t in range(nts):
         if ps[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's',
@@ -513,6 +526,8 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, time_interval
     plt.tick_params(labelsize=ticksize)
     plt.xlabel(xlabel, fontsize=fontsize)
     plt.ylabel(ylabel, fontsize=fontsize)
+
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
@@ -625,6 +640,17 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
                 else:
                     ps[t] = 0
 
+    print('\nSignificant time-windows:')
+    for t in range(nts):
+        if t == 0 and ps[t] == 1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps[t] == 1 and ps[t - 1] == 0:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps[t] == 1 and ps[t + 1] == 0:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps[t] == 1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
     for t in range(nts):
         if ps[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's', color=color, alpha=0.8,
@@ -652,6 +678,8 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
     plt.tick_params(labelsize=ticksize)
     plt.xlabel(xlabel, fontsize=fontsize)
     plt.ylabel(ylabel, fontsize=fontsize)
+
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
@@ -659,9 +687,10 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
 ' a function for plotting the differences of time-by-time decoding accuracies between two conditions '
 
 def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True,
-                                clusterp=0.05, stats_time=[0, 1], color1='r', color2='b', xlim=[0, 1], ylim=[0.4, 0.8],
-                                xlabel='Time (s)', ylabel='Decoding Accuracy', figsize=[6.4, 3.6], x0=0, ticksize=12,
-                                fontsize=16, markersize=2, title=None, title_fontsize=16, avgshow=False):
+                                clusterp=0.05, stats_time=[0, 1], color1='r', color2='b', label1='Condition1',
+                                label2='Condition2', xlim=[0, 1], ylim=[0.4, 0.8], xlabel='Time (s)',
+                                ylabel='Decoding Accuracy', figsize=[6.4, 3.6], x0=0, ticksize=12, fontsize=16,
+                                markersize=2, legend_fontsize=14, title=None, title_fontsize=16, avgshow=False):
 
     """
     Plot the differences of time-by-time decoding accuracies between two conditions
@@ -696,6 +725,10 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
         The color for the curve under condition1.
     color2 : matplotlib color or None. Default is 'r'.
         The color for the curve under condition2.
+    label1 : string-array. Default is 'Condition1'.
+        The Label of acc1's condition.
+    label2 : string-array. Default is 'Condition2'.
+        The Label of acc2's condition.
     xlim : array or list [xmin, xmax]. Default is [0, 1].
         The x-axis (time) view lims.
     ylim : array or list [ymin, ymax]. Default is [0.4, 0.8].
@@ -714,6 +747,8 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
         The fontsize of the labels.
     markersize : int or float. Default is 2.
         The size of significant marker.
+    legend_fontsize : int or float. Default is 14.
+        The fontsize of the legend.
     title : string-array. Default is None.
         The title of the figure.
     title_fontsize : int or float. Default is 16.
@@ -789,13 +824,57 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
                     ps2[t] = 1
                 else:
                     ps2[t] = 0
-                if ttest_rel(acc1[:, t], acc1[:, t], alternative="greater")[1] < p/2:
+                if ttest_rel(acc1[:, t], acc2[:, t], alternative="greater")[1] < p/2:
                     ps[t] = 1
-                elif ttest_rel(acc1[:, t], acc1[:, t], alternative="less")[1] < p/2:
+                elif ttest_rel(acc1[:, t], acc2[:, t], alternative="less")[1] < p/2:
                     ps[t] = -1
                 else:
                     ps[t] = 0
 
+    print('\nSignificant time-windows for condition 1:')
+    for t in range(nts):
+        if t == 0 and ps1[t] == 1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps1[t] == 1 and ps1[t - 1] == 0:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps1[t] == 1 and ps1[t + 1] == 0:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps1[t] == 1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
+    print('\nSignificant time-windows for condition 2:')
+    for t in range(nts):
+        if t == 0 and ps2[t] == 1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps2[t] == 1 and ps2[t - 1] == 0:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps2[t] == 1 and ps2[t + 1] == 0:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps2[t] == 1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
+    print('\nSignificant time-windows for condition 1 > condition 2:')
+    for t in range(nts):
+        if t == 0 and ps[t] == 1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps[t] == 1 and ps2[t - 1] < 1:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps[t] == 1 and ps[t + 1] < 1:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps[t] == 1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
+    print('\nSignificant time-windows for condition 2 > condition 1:')
+    for t in range(nts):
+        if t == 0 and ps[t] == -1:
+            print(str(int(start_time * 1000)) + 'ms to ', end='')
+        if t > 0 and ps[t] == -1 and ps2[t - 1] > -1:
+            print(str(int((start_time + t * tstep) * 1000)) + 'ms to ', end='')
+        if t < nts - 1 and ps[t] == -1 and ps[t + 1] > -1:
+            print(str(int((start_time + (t + 1) * tstep) * 1000)) + 'ms')
+        if t == nts - 1 and ps[t] == -1:
+            print(str(int(stats_time[1] * 1000)) + 'ms')
+
     for t in range(nts):
         if ps1[t] == 1:
             plt.plot(t*tstep+start_time+0.5*tstep, (ymaxlim-yminlim)*0.95+yminlim, 's', color=color1, alpha=0.8,
@@ -827,13 +906,19 @@ def plot_tbyt_diff_decoding_acc(acc1, acc2, start_time=0, end_time=1, time_inter
     if avgshow is True:
         plt.plot(x, avg1, color=color1, alpha=0.95)
         plt.plot(x, avg2, color=color2, alpha=0.95)
-    plt.fill_between(x, avg1+err1, avg1-err1, facecolor=color1, alpha=0.75)
-    plt.fill_between(x, avg2+err2, avg2-err2, facecolor=color2, alpha=0.75)
+    plt.fill_between(x, avg1+err1, avg1-err1, facecolor=color1, alpha=0.75, label=label1)
+    plt.fill_between(x, avg2+err2, avg2-err2, facecolor=color2, alpha=0.75, label=label2)
     plt.ylim(yminlim, ymaxlim)
     plt.xlim(xlim[0], xlim[1])
     plt.tick_params(labelsize=ticksize)
     plt.xlabel(xlabel, fontsize=fontsize)
     plt.ylabel(ylabel, fontsize=fontsize)
+    plt.legend()
+    ax = plt.gca()
+    leg = ax.get_legend()
+    ltext = leg.get_texts()
+    plt.setp(ltext, fontsize=legend_fontsize)
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps1, ps2, ps
@@ -985,6 +1070,8 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
     plt.tick_params(labelsize=ticksize)
     plt.xlabel(xlabel, fontsize=fontsize)
     plt.ylabel(ylabel, fontsize=fontsize)
+
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
@@ -1142,6 +1229,8 @@ def plot_ct_diff_decoding_acc(acc1, acc2, start_timex=0, end_timex=1, start_time
     plt.tick_params(labelsize=ticksize)
     plt.xlabel(xlabel, fontsize=fontsize)
     plt.ylabel(ylabel, fontsize=fontsize)
+
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
@@ -1290,6 +1379,7 @@ def plot_corrs_hotmap(corrs, chllabels=None, time_unit=[0, 0.1], lim=[0, 1], smo
     plt.ylabel("Channel", fontsize=20)
     plt.xlabel("Time (s)", fontsize=20)
 
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return 0
@@ -1478,6 +1568,7 @@ def plot_corrs_hotmap_withstats(corrs, chllabels=None, time_unit=[0, 0.1], lim=[
     plt.ylabel(ylabel, fontsize=20)
     plt.xlabel(xlabel, fontsize=20)
 
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
@@ -1620,6 +1711,7 @@ def plot_nps_hotmap(similarities, chllabels=None, time_unit=[0, 0.1], lim=[0, 1]
     plt.ylabel("Channel", fontsize=20)
     plt.xlabel("Time (s)", fontsize=20)
 
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return 0
@@ -1807,6 +1899,7 @@ def plot_t_hotmap_withstats(results, chllabels=None, time_unit=[0, 0.1], lim=[-7
     plt.ylabel(ylabel, fontsize=20)
     plt.xlabel(xlabel, fontsize=20)
 
+    plt.title(title, fontsize=title_fontsize)
     plt.show()
 
     return ps
